@@ -8,7 +8,7 @@ use NBI::Opts;
 use base qw(Exporter);
 our @ISA = qw(Exporter);
 our @EXPORT = qw(Job Opts load_config %FORMAT_STRINGS);
-$NBI::Slurm::VERSION = '0.4.9';
+$NBI::Slurm::VERSION = '0.4.10';
 
 
 
@@ -69,10 +69,11 @@ sub has_squeue {
 }
 
 sub queues {
+  my $can_fail = shift;
   # Retrieve queues from SLURM
   my $cmd = "sinfo --format '%P' --noheader";
   my @output = `$cmd 2>/dev/null`;
-  if ($? != 0) {
+  if ($? != 0 and ! $can_fail) {
     Carp::croak "ERROR NBI::Slurm: sinfo failed. Are you in a SLURM cluster?\n";
   }
   chomp @output;
@@ -81,7 +82,7 @@ sub queues {
 
 sub valid_queue {
   my $queue = shift;
-  my @queues = queues();
+  my @queues = queues(1);
   my @input_queues = split(/,/, $queue);
   foreach my $input_queue (@input_queues) {
     if (! grep { $_ eq $input_queue } @queues) {
@@ -90,6 +91,35 @@ sub valid_queue {
   }
   return 1;
 }
+
+
+sub days_since_update {
+    my $file_path = shift;
+
+    # Check if the required modules can be loaded
+    eval {
+        require File::Spec;
+        require Time::Piece;
+        require Time::Seconds;
+    };
+    if ($@) {
+        return -1;  # Failed to load required module(s)
+    }
+
+    # Check if the file exists
+    unless (-e $file_path) {
+        return -1;  # File not found
+    }
+
+    # Get the file's last modification time
+    my $last_modified = (stat($file_path))[9];
+
+    # Calculate the number of days since the last modification
+    my $current_time = time();
+    my $days_since_update = int(($current_time - $last_modified) / (24 * 60 * 60));
+
+    return $days_since_update;
+}
 1;
 
 __END__
@@ -104,7 +134,7 @@ NBI::Slurm - NBI Slurm module
 
 =head1 VERSION
 
-version 0.4.9
+version 0.4.10
 
 =head1 SYNOPSIS
 
@@ -166,18 +196,6 @@ One popular scheduler used in HPC environments is B<SLURM> (Simple Linux Utility
 
 SLURM's design philosophy focuses on scalability, fault-tolerance, and extensibility, making it a popular choice for many research institutions and supercomputing centers.
 
-=head1 CLASSES
-
-The C<NBI::Slurm> package includes the following classes:
-
-=over 4
-
-=item * L<NBI::Job>: Represents a job to be submitted to SLURM.
-
-=item * L<NBI::Opts>: Represents the SLURM options for a job.
-
-=back
-
 =head1 METHODS
 
 =over 4
@@ -198,6 +216,22 @@ Retrieve queues from SLURM.
 
 Check if a queue is valid.
 
+=item * B<days_since_update>
+
+Calculate the number of days since a file was last modified.
+
+=back
+
+=head1 CLASSES
+
+The C<NBI::Slurm> package includes the following classes:
+
+=over 4
+
+=item * L<NBI::Job>: Represents a job to be submitted to SLURM.
+
+=item * L<NBI::Opts>: Represents the SLURM options for a job.
+
 =back
 
 Please refer to the documentation for each class for more information on their methods and usage.
